Stan Math Library: Member List

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

stan::math::welford_var_estimator Member List

This is the complete list of members for stan::math::welford_var_estimator, including all inherited members.

_m | stan::math::welford_var_estimator | protected
_m2 | stan::math::welford_var_estimator | protected
_num_samples | stan::math::welford_var_estimator | protected
add_sample(const Eigen::VectorXd &q) | stan::math::welford_var_estimator | inline
num_samples() | stan::math::welford_var_estimator | inline
restart() | stan::math::welford_var_estimator | inline
sample_mean(Eigen::VectorXd &mean) | stan::math::welford_var_estimator | inline
sample_variance(Eigen::VectorXd &var) | stan::math::welford_var_estimator | inline
welford_var_estimator(int n) | stan::math::welford_var_estimator | inlineexplicit

[ Stan Home Page ] © 2011–2016, Stan Development Team.